@@ -1,9 +1,7 @@
-use thiserror::Error;
-
 /// Graph errors.
-#[derive(Debug, Error)]
+#[derive(Debug, thiserror::Error)]
 #[non_exhaustive]
-pub enum GraphError {
+pub enum Error {
     /// The graph is missing relevant information.
     #[error("incomplete graph: {value:?}")]
     IncompleteGraph { value: String },
